@@ -14,7 +14,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 NAME
 
@@ -630,7 +630,7 @@ our %curl_header_defaults = (
 
 sub as_curl($self,%options) {
     $options{ curl } = 'curl'
-        if ! exists $options{ long_options };
+        if ! exists $options{ curl };
     $options{ long_options } = 1
         if ! exists $options{ long_options };
 
@@ -692,6 +692,83 @@ sub as_curl($self,%options) {
         @request_commands;
 }
 
+# These are what wget uses as defaults, not what Perl should use as default!
+our %wget_header_defaults = (
+    'Accept'          => '*/*',
+    'Accept-Encoding' => 'identity',
+    'User-Agent' => 'Wget/1.21',
+    'Connection' => 'Keep-Alive',
+);
+
+sub as_wget($self,%options) {
+    $options{ wget } = 'wget'
+        if ! exists $options{ wget };
+    $options{ long_options } = 1
+        if ! exists $options{ long_options };
+
+    my @request_commands;
+
+    if( $self->method ne 'GET' ) {
+        if( $self->method eq 'POST' and $self->body ) {
+            # This is implied by '--post-data', below
+        } else {
+            push @request_commands,
+                '--method' => $self->method;
+        };
+    };
+
+    if( scalar keys %{ $self->headers }) {
+        for my $h (sort keys %{$self->headers}) {
+            my $v = $self->headers->{$h};
+
+            my $default;
+            if( exists $wget_header_defaults{ $h }) {
+                $default = $wget_header_defaults{ $h };
+            };
+
+            if( ! ref $v ) {
+                $v = [$v];
+            };
+            for my $val (@$v) {
+                if( !defined $default or $val ne $default ) {
+                    # also skip the Host: header if it derives from $uri
+                    if( $h eq 'Host' and ($val eq $self->uri->host_port
+                                          or $val eq $self->uri->host   )) {
+                        # trivial host header
+                    } elsif( $h eq 'User-Agent' ) {
+                        push @request_commands,
+                            '--user-agent',
+                            $val;
+                    } else {
+                        push @request_commands,
+                            '--header',
+                            "$h: $val";
+                    };
+                };
+            };
+        };
+    };
+
+    if( my $body = $self->body ) {
+        if( $self->method eq 'POST' ) {
+            push @request_commands,
+                '--post-data',
+                $body;
+        } else {
+            push @request_commands,
+                '--body-data',
+                $body;
+        };
+    };
+
+    push @request_commands, $self->uri;
+
+    return
+        #(defined $options{ curl } ? $options{curl} : () ),
+        @request_commands;
+}
+
+
 =head2 C<< $r->clone >>
 
 Returns a shallow copy of the object
