@@ -9,7 +9,7 @@ use JSON;
 use PerlX::Maybe;
 use HTTP::Request::CurlParameters;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 NAME
 
@@ -53,9 +53,17 @@ This is mostly a factory class for L<HTTP::Request::CurlParameters> objects.
 
 =cut
 
-sub new( $class, $fetch ) {
+sub new( $class, $fetch, @rest ) {
+    my %options;
+
+    if( @rest ) {
+        %options = ($fetch, @rest);
+    } else {
+        $options{ fetch } = $fetch;
+    };
+
+    $fetch = delete $options{ fetch };
 
-#use Regexp::Debugger;
     $fetch =~ m!\A\s*(await\s+)?
                   fetch\s*\(\s*"(?<uri>(?:[^[\\"]+|\\.)+)"\s*(?:,\s*
                   (?<options>\{.*\}))?\s*
